caellion-python-commons: caellion.pycommons.hashing.file_hashing.AlreadyDoneException Class Reference

caellion-python-commons

caellion.pycommons.hashing.file_hashing.AlreadyDoneException Class Reference

This exception is raised when hashing was requested on a FileHasher that has already finished hashing. More...

Inheritance diagram for caellion.pycommons.hashing.file_hashing.AlreadyDoneException:

## Detailed Description

This exception is raised when hashing was requested on a FileHasher that has already finished hashing.

Definition at line 16 of file file_hashing.py.

The documentation for this class was generated from the following file:

- caellion/pycommons/hashing/file_hashing.py